@@ -5,7 +5,7 @@
 # later version. See the file COPYING for details.
 
 class cv:
-    trs = (
+    trs: tuple[tuple[float, float, float, float, float, float, float, float]] = (
         (0.00, 0.15, 0.30, 0.50, 0.65, 0.80, 0.90, 1.00),
         (1.00, 0.00, 0.15, 0.30, 0.50, 0.65, 0.80, 0.90),
         (0.90, 1.00, 0.00, 0.15, 0.30, 0.50, 0.65, 0.80),
